//=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//Ridici software pro displej Densitron DD-25664GE-1A
//pro procesor ATmega32

//=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

//definice hlavicek
#include <inttypes.h> 
#define F_CPU 4000000UL  // 4 MHz
#include <util/delay.h>                                            
#include <stdio.h>
#include <stdlib.h>
#include <avr/io.h>
#include <string.h>
//#define		I80				// 8-bit 80XX Parallel

//definice datovych typu
#ifndef _mydefs_h_
#define _mydefs_h_


typedef unsigned char  u8;
typedef   signed char  s8;
typedef unsigned short u16;
typedef   signed short s16;
typedef unsigned long  u32;
typedef   signed long  s32;


#define vu8(x)  (*(volatile u8*)&(x))
#define vs8(x)  (*(volatile s8*)&(x))
#define vu16(x) (*(volatile u16*)&(x))
#define vs16(x) (*(volatile s16*)&(x))
#define vu32(x) (*(volatile u32*)&(x))
#define vs32(x) (*(volatile s32*)&(x))


struct bits {
  u8 b0:1;
  u8 b1:1;
  u8 b2:1;
  u8 b3:1;
  u8 b4:1;
  u8 b5:1;
  u8 b6:1;
  u8 b7:1;
} __attribute__((__packed__));

#define SBIT(port,pin) ((*(volatile struct bits*)&port).b##pin)


#endif


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Definice vyvodu procesoru
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#define xData        PORTA        /**< brana pro prenos dat   */ 

#define PWR       SBIT(PORTB, 7)        /**< Vyvod spousteni napajeni displeje   */
#define E       SBIT(PORTB, 0)        /**< Enable vyvod   */
#define RW       SBIT(PORTB, 1)        /**< Read/Write vyvod   */
#define BS0       SBIT(PORTB, 2)        /**< Nastaveni modu komunikace  */
#define BS1       SBIT(PORTB, 3)        /**< Nastaveni modu komunikace   */
#define DC       SBIT(PORTB, 4)        /**< Vyvod Data/Control   */
#define CS       SBIT(PORTB, 5)        /**< vyvod Chip Select   */
#define RES       SBIT(PORTB, 6)        /**< Vyvod pro Reset   */


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Definice sekvenci pro zapisovani dat / prikazu do radice
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void Write_Command(unsigned char Data)
{
	DC=0;
	CS=0;
	RW=0;
	E=1;
	xData=Data;
	E=0;
	RW=1;
	CS=1;
	DC=1;
}


void Write_Data(unsigned char Data)
{
	DC=1;
	CS=0;
	RW=0;
	E=1;
	xData=Data;
	E=0;
	RW=1;
	CS=1;
	DC=1;
}

//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Definice ridicich prikazu
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void Set_Column_Address(unsigned char a, unsigned char b) // nastaveni rozsahu sloupcu pro zapis
{
	Write_Command(0x15);
	Write_Data(a);				// Default => 0x00
	Write_Data(b);				// Default => 0x77
}


void Set_Write_RAM() // nastaveni radice na zapis do pameti
{
	Write_Command(0x5C);			// Pristup do vnitrni pameti DDRAM
}


void Set_Read_RAM() // nastaveni radice na cteni z pameti
{
	Write_Command(0x5D);			// Pristup do vnitrni pameti DDRAM
}


void Set_Row_Address(unsigned char a, unsigned char b) // nastaveni rozsahu radku pro zapis
{
	Write_Command(0x75);
	Write_Data(a);				// Default => 0x00
	Write_Data(b);				// Default => 0x7F
}


void Set_Remap_Format(unsigned char d) // nastaveni premapovani (podle manualu) 
{
	Write_Command(0xA0);
	Write_Data(d);				// Vychozi => 0x40
	Write_Data(0x11);						
}


void Set_Start_Line(unsigned char d) //nastaveni pocatecniho radku
{
	Write_Command(0xA1);
	Write_Data(d);				// Default => 0x00
}


void Set_Display_Offset(unsigned char d) // nastaveni ofsetu displeje
{
	Write_Command(0xA2);
	Write_Data(d);				// Default => 0x00
}


void Set_Display_Mode(unsigned char d) //nastaveni modu displeje (viz nize)
{
	Write_Command(0xA4|d);			// Vychozi => 0xA4
						//   0xA4 (0x00) => Normalni displej
						//   0xA5 (0x01) => Cely displej zapnuty
						//   0xA6 (0x02) => Cely displej vypnuty
						//   0xA7 (0x03) => Inversni displej
}


void Set_Partial_Display(unsigned char a, unsigned char b, unsigned char c)
{
	Write_Command(0xA8|a);
						// Default => 0x8F
					
	if(a == 0x00)
	{
		Write_Data(b);
		Write_Data(c);
	}
}


void Set_Function_Selection(unsigned char d)
{
	Write_Command(0xAB);
	Write_Data(d);				// Default => 0x8F
}


void Set_Display_On_Off(unsigned char d) //Vypnuti / zapnuti displeje
{
	Write_Command(0xAE|d);			// Default => 0xAE
}


void Set_Phase_Length(unsigned char d) //nastaveni napajecich parametru
{
	Write_Command(0xB1);
	Write_Data(d);				// Default => 0x74
						//   A[3:0] => Phase 1 Period in 5~31 Clocks
						//   A[7:4] => Phase 2 Period in 3~15 Clocks
}


void Set_Display_Clock(unsigned char d) // nastaveni hodinoveho signalu radice
{
	Write_Command(0xB3);
	Write_Data(d);				// Default => 0xD0
						//   A[3:0] => Display Clock Divider
						//   A[7:4] => Oscillator Frequency
}


void Set_Enhancement_A(unsigned char a, unsigned char b)
{
	Write_Command(0xB4);			// Display Enhancement A
	Write_Data(0xA0|a);			//   Default => 0xA2
	Write_Data(0x05|b);			//   Default => 0xB5
}


void Set_GPIO(unsigned char d)
{
	Write_Command(0xB5);
	Write_Data(d);				// Default => 0xD0
						//   A[1:0] => Display Clock Divider
						//   A[3:2] => Oscillator Frequency
}


void Set_Precharge_Period(unsigned char d)
{
	Write_Command(0xB6);
	Write_Data(d);				// Default => 0x08
}


void Set_Precharge_Voltage(unsigned char d)
{
	Write_Command(0xBB);
	Write_Data(d);				// Default => 0x17
						//   Connects to VCOMH
}


void Set_VCOMH(unsigned char d)
{
	Write_Command(0xBE);
	Write_Data(d);				// Default => 0x04
						//   0.80*VCC
}


void Set_Contrast_Current(unsigned char a)
{
	Write_Command(0xC1);
	Write_Data(a);				// Default => 0x7F
}


void Set_Master_Current(unsigned char d)
{
	Write_Command(0xC7);
	Write_Data(d);				// Default => 0x0f
}


void Set_Multiplex_Ratio(unsigned char d)
{
	Write_Command(0xCA);
	Write_Data(d);				// Default => 0x7F
}


void Set_Enhancement_B(unsigned char d)
{
	Write_Command(0xD1);			// Display Enhancement B
	Write_Data(0x82|d);			//   Default => 0xA2
	Write_Data(0x20);
}


void Set_Command_Lock(unsigned char d)
{
	Write_Command(0xFD);
	Write_Data(0x12|d);			// Default => 0x12
}


//=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Definice grafiky a fontu (kvuli nedostatku pameti jsou recka pismena zakomentovana)
//=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
static char logo_FEKT[] = {
	0,0,0,0,2,0,0,0,1,0,0,0,0,2,0,0,0,0,1,0,0,0,2,0,
	0,0,0,0,0,0,0,1,0,0,5,0,1,2,0,0,0,0,2,0,1,0,0,0,
	1,0,1,0,0,0,9,9,13,14,11,12,12,14,12,13,12,12,3,0,1,0,2,0,
	0,1,0,0,13,12,13,13,13,11,14,11,13,14,13,13,14,13,13,13,8,0,0,0,
	0,10,13,13,12,13,13,13,13,5,1,12,12,12,10,11,11,13,13,13,13,13,13,5,
	0,12,11,14,13,9,13,12,0,0,8,12,14,13,7,2,6,12,11,13,13,10,13,6,
	0,14,14,11,11,12,14,0,0,0,14,12,12,13,0,0,0,5,13,13,11,13,12,7,
	0,9,12,13,13,13,0,0,0,9,13,13,13,0,0,0,1,0,5,13,13,12,14,4,
	0,9,12,12,14,8,0,0,0,12,14,11,0,0,0,0,4,0,0,13,12,12,14,0,
	1,0,14,12,11,6,0,0,0,13,11,14,0,5,10,14,5,0,3,8,12,13,12,0,
	0,0,12,13,13,0,1,0,0,13,10,5,13,12,13,8,0,1,0,8,14,10,12,1,
	0,0,8,12,13,0,0,0,1,11,10,13,13,13,11,9,0,0,0,5,12,10,4,0,
	0,0,4,14,12,4,1,0,0,14,15,5,4,12,13,0,2,0,1,8,11,15,0,0,
	0,1,0,11,14,8,0,0,0,1,0,0,14,10,4,0,0,0,0,13,13,8,1,0,
	0,0,0,2,13,13,1,0,0,0,0,5,14,9,5,1,0,0,10,13,13,0,0,0,
	0,1,0,0,12,14,12,0,0,0,0,12,12,12,7,0,0,4,13,12,4,0,0,0,
	0,0,0,0,5,10,14,12,0,1,0,12,14,0,0,0,1,12,12,14,0,1,0,0,
	0,0,1,0,0,12,11,13,14,4,0,1,0,0,0,11,12,14,14,4,0,0,0,0,
	0,0,0,0,1,0,13,13,13,12,13,11,13,13,14,13,13,11,6,0,0,0,0,0,
	0,1,0,0,0,0,0,12,12,13,14,13,11,13,13,12,12,8,0,0,0,0,0,0,
	0,0,0,0,1,0,0,1,14,12,12,13,14,11,13,12,9,2,0,0,0,0,0,1,
	0,1,0,0,0,0,0,0,0,10,13,12,11,13,13,5,0,0,0,1,0,0,0,0,
	1,0,0,1,0,0,1,0,0,0,1,13,13,13,0,0,0,2,0,1,0,0,1,0,
	0,0,0,0,0,0,0,0,0,0,0,0,7,0,2,0,0,0,0,0,0,1,0,0
	};

//ASCII tabulka (latinka, ekvivalent Times New Roman, 5x8px)
unsigned char Ascii_1[241][5]={		
	{0x00,0x00,0x00,0x00,0x00},		//
	{0x00,0x00,0x4F,0x00,0x00},		//   (  1)  ! - 0x0021 Exclamation Mark
	{0x00,0x07,0x00,0x07,0x00},		//   (  2)  " - 0x0022 Quotation Mark
	{0x14,0x7F,0x14,0x7F,0x14},		//   (  3)  # - 0x0023 Number Sign
	{0x24,0x2A,0x7F,0x2A,0x12},		//   (  4)  $ - 0x0024 Dollar Sign
	{0x23,0x13,0x08,0x64,0x62},		//   (  5)  % - 0x0025 Percent Sign
	{0x36,0x49,0x55,0x22,0x50},		//   (  6)  & - 0x0026 Ampersand
	{0x00,0x05,0x03,0x00,0x00},		//   (  7)  ' - 0x0027 Apostrophe
	{0x00,0x1C,0x22,0x41,0x00},		//   (  8)  ( - 0x0028 Left Parenthesis
	{0x00,0x41,0x22,0x1C,0x00},		//   (  9)  ) - 0x0029 Right Parenthesis
	{0x14,0x08,0x3E,0x08,0x14},		//   ( 10)  * - 0x002A Asterisk
	{0x08,0x08,0x3E,0x08,0x08},		//   ( 11)  + - 0x002B Plus Sign
	{0x00,0x50,0x30,0x00,0x00},		//   ( 12)  , - 0x002C Comma
	{0x08,0x08,0x08,0x08,0x08},		//   ( 13)  - - 0x002D Hyphen-Minus
	{0x00,0x60,0x60,0x00,0x00},		//   ( 14)  . - 0x002E Full Stop
	{0x20,0x10,0x08,0x04,0x02},		//   ( 15)  / - 0x002F Solidus
	{0x3E,0x51,0x49,0x45,0x3E},		//   ( 16)  0 - 0x0030 Digit Zero
	{0x00,0x42,0x7F,0x40,0x00},		//   ( 17)  1 - 0x0031 Digit One
	{0x42,0x61,0x51,0x49,0x46},		//   ( 18)  2 - 0x0032 Digit Two
	{0x21,0x41,0x45,0x4B,0x31},		//   ( 19)  3 - 0x0033 Digit Three
	{0x18,0x14,0x12,0x7F,0x10},		//   ( 20)  4 - 0x0034 Digit Four
	{0x27,0x45,0x45,0x45,0x39},		//   ( 21)  5 - 0x0035 Digit Five
	{0x3C,0x4A,0x49,0x49,0x30},		//   ( 22)  6 - 0x0036 Digit Six
	{0x01,0x71,0x09,0x05,0x03},		//   ( 23)  7 - 0x0037 Digit Seven
	{0x36,0x49,0x49,0x49,0x36},		//   ( 24)  8 - 0x0038 Digit Eight
	{0x06,0x49,0x49,0x29,0x1E},		//   ( 25)  9 - 0x0039 Dight Nine
	{0x00,0x36,0x36,0x00,0x00},		//   ( 26)  : - 0x003A Colon
	{0x00,0x56,0x36,0x00,0x00},		//   ( 27)  ; - 0x003B Semicolon
	{0x08,0x14,0x22,0x41,0x00},		//   ( 28)  < - 0x003C Less-Than Sign
	{0x14,0x14,0x14,0x14,0x14},		//   ( 29)  = - 0x003D Equals Sign
	{0x00,0x41,0x22,0x14,0x08},		//   ( 30)  > - 0x003E Greater-Than Sign
	{0x02,0x01,0x51,0x09,0x06},		//   ( 31)  ? - 0x003F Question Mark
	{0x32,0x49,0x79,0x41,0x3E},		//   ( 32)  @ - 0x0040 Commercial At
	{0x7E,0x11,0x11,0x11,0x7E},		//   ( 33)  A - 0x0041 Latin Capital Letter A
	{0x7F,0x49,0x49,0x49,0x36},		//   ( 34)  B - 0x0042 Latin Capital Letter B
	{0x3E,0x41,0x41,0x41,0x22},		//   ( 35)  C - 0x0043 Latin Capital Letter C
	{0x7F,0x41,0x41,0x22,0x1C},		//   ( 36)  D - 0x0044 Latin Capital Letter D
	{0x7F,0x49,0x49,0x49,0x41},		//   ( 37)  E - 0x0045 Latin Capital Letter E
	{0x7F,0x09,0x09,0x09,0x01},		//   ( 38)  F - 0x0046 Latin Capital Letter F
	{0x3E,0x41,0x49,0x49,0x7A},		//   ( 39)  G - 0x0047 Latin Capital Letter G
	{0x7F,0x08,0x08,0x08,0x7F},		//   ( 40)  H - 0x0048 Latin Capital Letter H
	{0x00,0x41,0x7F,0x41,0x00},		//   ( 41)  I - 0x0049 Latin Capital Letter I
	{0x20,0x40,0x41,0x3F,0x01},		//   ( 42)  J - 0x004A Latin Capital Letter J
	{0x7F,0x08,0x14,0x22,0x41},		//   ( 43)  K - 0x004B Latin Capital Letter K
	{0x7F,0x40,0x40,0x40,0x40},		//   ( 44)  L - 0x004C Latin Capital Letter L
	{0x7F,0x02,0x0C,0x02,0x7F},		//   ( 45)  M - 0x004D Latin Capital Letter M
	{0x7F,0x04,0x08,0x10,0x7F},		//   ( 46)  N - 0x004E Latin Capital Letter N
	{0x3E,0x41,0x41,0x41,0x3E},		//   ( 47)  O - 0x004F Latin Capital Letter O
	{0x7F,0x09,0x09,0x09,0x06},		//   ( 48)  P - 0x0050 Latin Capital Letter P
	{0x3E,0x41,0x51,0x21,0x5E},		//   ( 49)  Q - 0x0051 Latin Capital Letter Q
	{0x7F,0x09,0x19,0x29,0x46},		//   ( 50)  R - 0x0052 Latin Capital Letter R
	{0x46,0x49,0x49,0x49,0x31},		//   ( 51)  S - 0x0053 Latin Capital Letter S
	{0x01,0x01,0x7F,0x01,0x01},		//   ( 52)  T - 0x0054 Latin Capital Letter T
	{0x3F,0x40,0x40,0x40,0x3F},		//   ( 53)  U - 0x0055 Latin Capital Letter U
	{0x1F,0x20,0x40,0x20,0x1F},		//   ( 54)  V - 0x0056 Latin Capital Letter V
	{0x3F,0x40,0x38,0x40,0x3F},		//   ( 55)  W - 0x0057 Latin Capital Letter W
	{0x63,0x14,0x08,0x14,0x63},		//   ( 56)  X - 0x0058 Latin Capital Letter X
	{0x07,0x08,0x70,0x08,0x07},		//   ( 57)  Y - 0x0059 Latin Capital Letter Y
	{0x61,0x51,0x49,0x45,0x43},		//   ( 58)  Z - 0x005A Latin Capital Letter Z
	{0x00,0x7F,0x41,0x41,0x00},		//   ( 59)  [ - 0x005B Left Square Bracket
	{0x02,0x04,0x08,0x10,0x20},		//   ( 60)  \ - 0x005C Reverse Solidus
	{0x00,0x41,0x41,0x7F,0x00},		//   ( 61)  ] - 0x005D Right Square Bracket
	{0x04,0x02,0x01,0x02,0x04},		//   ( 62)  ^ - 0x005E Circumflex Accent
	{0x40,0x40,0x40,0x40,0x40},		//   ( 63)  _ - 0x005F Low Line
	{0x01,0x02,0x04,0x00,0x00},		//   ( 64)  ` - 0x0060 Grave Accent
	{0x20,0x54,0x54,0x54,0x78},		//   ( 65)  a - 0x0061 Latin Small Letter A
	{0x7F,0x48,0x44,0x44,0x38},		//   ( 66)  b - 0x0062 Latin Small Letter B
	{0x38,0x44,0x44,0x44,0x20},		//   ( 67)  c - 0x0063 Latin Small Letter C
	{0x38,0x44,0x44,0x48,0x7F},		//   ( 68)  d - 0x0064 Latin Small Letter D
	{0x38,0x54,0x54,0x54,0x18},		//   ( 69)  e - 0x0065 Latin Small Letter E
	{0x08,0x7E,0x09,0x01,0x02},		//   ( 70)  f - 0x0066 Latin Small Letter F
	{0x06,0x49,0x49,0x49,0x3F},		//   ( 71)  g - 0x0067 Latin Small Letter G
	{0x7F,0x08,0x04,0x04,0x78},		//   ( 72)  h - 0x0068 Latin Small Letter H
	{0x00,0x44,0x7D,0x40,0x00},		//   ( 73)  i - 0x0069 Latin Small Letter I
	{0x20,0x40,0x44,0x3D,0x00},		//   ( 74)  j - 0x006A Latin Small Letter J
	{0x7F,0x10,0x28,0x44,0x00},		//   ( 75)  k - 0x006B Latin Small Letter K
	{0x00,0x41,0x7F,0x40,0x00},		//   ( 76)  l - 0x006C Latin Small Letter L
	{0x7C,0x04,0x18,0x04,0x7C},		//   ( 77)  m - 0x006D Latin Small Letter M
	{0x7C,0x08,0x04,0x04,0x78},		//   ( 78)  n - 0x006E Latin Small Letter N
	{0x38,0x44,0x44,0x44,0x38},		//   ( 79)  o - 0x006F Latin Small Letter O
	{0x7C,0x14,0x14,0x14,0x08},		//   ( 80)  p - 0x0070 Latin Small Letter P
	{0x08,0x14,0x14,0x18,0x7C},		//   ( 81)  q - 0x0071 Latin Small Letter Q
	{0x7C,0x08,0x04,0x04,0x08},		//   ( 82)  r - 0x0072 Latin Small Letter R
	{0x48,0x54,0x54,0x54,0x20},		//   ( 83)  s - 0x0073 Latin Small Letter S
	{0x04,0x3F,0x44,0x40,0x20},		//   ( 84)  t - 0x0074 Latin Small Letter T
	{0x3C,0x40,0x40,0x20,0x7C},		//   ( 85)  u - 0x0075 Latin Small Letter U
	{0x1C,0x20,0x40,0x20,0x1C},		//   ( 86)  v - 0x0076 Latin Small Letter V
	{0x3C,0x40,0x30,0x40,0x3C},		//   ( 87)  w - 0x0077 Latin Small Letter W
	{0x44,0x28,0x10,0x28,0x44},		//   ( 88)  x - 0x0078 Latin Small Letter X
	{0x0C,0x50,0x50,0x50,0x3C},		//   ( 89)  y - 0x0079 Latin Small Letter Y
	{0x44,0x64,0x54,0x4C,0x44},		//   ( 90)  z - 0x007A Latin Small Letter Z
	{0x00,0x08,0x36,0x41,0x00},		//   ( 91)  { - 0x007B Left Curly Bracket
	{0x00,0x00,0x7F,0x00,0x00},		//   ( 92)  | - 0x007C Vertical Line
	{0x00,0x41,0x36,0x08,0x00},		//   ( 93)  } - 0x007D Right Curly Bracket
	{0x02,0x01,0x02,0x04,0x02},		//   ( 94)  ~ - 0x007E Tilde
	{0x3E,0x55,0x55,0x41,0x22},		//   ( 95)  C - 0x0080 <Control>
	{0x00,0x00,0x00,0x00,0x00},		//   ( 96)    - 0x00A0 No-Break Space
	{0x00,0x00,0x79,0x00,0x00},		//   ( 97)  ! - 0x00A1 Inverted Exclamation Mark
	{0x18,0x24,0x74,0x2E,0x24},		//   ( 98)  c - 0x00A2 Cent Sign
	{0x48,0x7E,0x49,0x42,0x40},		//   ( 99)  L - 0x00A3 Pound Sign
	{0x5D,0x22,0x22,0x22,0x5D},		//   (100)  o - 0x00A4 Currency Sign
	{0x15,0x16,0x7C,0x16,0x15},		//   (101)  Y - 0x00A5 Yen Sign
	{0x00,0x00,0x77,0x00,0x00},		//   (102)  | - 0x00A6 Broken Bar
	{0x0A,0x55,0x55,0x55,0x28},		//   (103)    - 0x00A7 Section Sign
	{0x00,0x01,0x00,0x01,0x00},		//   (104)  " - 0x00A8 Diaeresis
	{0x00,0x0A,0x0D,0x0A,0x04},		//   (105)    - 0x00AA Feminine Ordinal Indicator
	{0x08,0x14,0x2A,0x14,0x22},		//   (106) << - 0x00AB Left-Pointing Double Angle Quotation Mark
	{0x04,0x04,0x04,0x04,0x1C},		//   (107)    - 0x00AC Not Sign
	{0x00,0x08,0x08,0x08,0x00},		//   (108)  - - 0x00AD Soft Hyphen
	{0x01,0x01,0x01,0x01,0x01},		//   (109)    - 0x00AF Macron
	{0x00,0x02,0x05,0x02,0x00},		//   (110)    - 0x00B0 Degree Sign
	{0x44,0x44,0x5F,0x44,0x44},		//   (111) +- - 0x00B1 Plus-Minus Sign
	{0x00,0x00,0x04,0x02,0x01},		//   (112)  ` - 0x00B4 Acute Accent
	{0x7E,0x20,0x20,0x10,0x3E},		//   (113)  u - 0x00B5 Micro Sign
	{0x06,0x0F,0x7F,0x00,0x7F},		//   (114)    - 0x00B6 Pilcrow Sign
	{0x00,0x18,0x18,0x00,0x00},		//   (115)  . - 0x00B7 Middle Dot
	{0x00,0x40,0x50,0x20,0x00},		//   (116)    - 0x00B8 Cedilla
	{0x00,0x0A,0x0D,0x0A,0x00},		//   (117)    - 0x00BA Masculine Ordinal Indicator
	{0x22,0x14,0x2A,0x14,0x08},		//   (118) >> - 0x00BB Right-Pointing Double Angle Quotation Mark
	{0x17,0x08,0x34,0x2A,0x7D},		//   (119) /4 - 0x00BC Vulgar Fraction One Quarter
	{0x17,0x08,0x04,0x6A,0x59},		//   (120) /2 - 0x00BD Vulgar Fraction One Half
	{0x30,0x48,0x45,0x40,0x20},		//   (121)  ? - 0x00BF Inverted Question Mark
	{0x70,0x29,0x26,0x28,0x70},		//   (122) `A - 0x00C0 Latin Capital Letter A with Grave
	{0x70,0x28,0x26,0x29,0x70},		//   (123) 'A - 0x00C1 Latin Capital Letter A with Acute
	{0x70,0x2A,0x25,0x2A,0x70},		//   (124) ^A - 0x00C2 Latin Capital Letter A with Circumflex
	{0x72,0x29,0x26,0x29,0x70},		//   (125) ~A - 0x00C3 Latin Capital Letter A with Tilde
	{0x70,0x29,0x24,0x29,0x70},		//   (126) "A - 0x00C4 Latin Capital Letter A with Diaeresis
	{0x70,0x2A,0x2D,0x2A,0x70},		//   (127)  A - 0x00C5 Latin Capital Letter A with Ring Above
	{0x7E,0x11,0x7F,0x49,0x49},		//   (128) AE - 0x00C6 Latin Capital Letter Ae
	{0x0E,0x51,0x51,0x71,0x11},		//   (129)  C - 0x00C7 Latin Capital Letter C with Cedilla
	{0x7C,0x55,0x56,0x54,0x44},		//   (130) `E - 0x00C8 Latin Capital Letter E with Grave
	{0x7C,0x55,0x56,0x54,0x44},		//   (131) 'E - 0x00C9 Latin Capital Letter E with Acute
	{0x7C,0x56,0x55,0x56,0x44},		//   (132) ^E - 0x00CA Latin Capital Letter E with Circumflex
	{0x7C,0x55,0x54,0x55,0x44},		//   (133) "E - 0x00CB Latin Capital Letter E with Diaeresis
	{0x00,0x45,0x7E,0x44,0x00},		//   (134) `I - 0x00CC Latin Capital Letter I with Grave
	{0x00,0x44,0x7E,0x45,0x00},		//   (135) 'I - 0x00CD Latin Capital Letter I with Acute
	{0x00,0x46,0x7D,0x46,0x00},		//   (136) ^I - 0x00CE Latin Capital Letter I with Circumflex
	{0x00,0x45,0x7C,0x45,0x00},		//   (137) "I - 0x00CF Latin Capital Letter I with Diaeresis
	{0x7F,0x49,0x49,0x41,0x3E},		//   (138)  D - 0x00D0 Latin Capital Letter Eth
	{0x7C,0x0A,0x11,0x22,0x7D},		//   (139) ~N - 0x00D1 Latin Capital Letter N with Tilde
	{0x38,0x45,0x46,0x44,0x38},		//   (140) `O - 0x00D2 Latin Capital Letter O with Grave
	{0x38,0x44,0x46,0x45,0x38},		//   (141) 'O - 0x00D3 Latin Capital Letter O with Acute
	{0x38,0x46,0x45,0x46,0x38},		//   (142) ^O - 0x00D4 Latin Capital Letter O with Circumflex
	{0x38,0x46,0x45,0x46,0x39},		//   (143) ~O - 0x00D5 Latin Capital Letter O with Tilde
	{0x38,0x45,0x44,0x45,0x38},		//   (144) "O - 0x00D6 Latin Capital Letter O with Diaeresis
	{0x22,0x14,0x08,0x14,0x22},		//   (145)  x - 0x00D7 Multiplcation Sign
	{0x2E,0x51,0x49,0x45,0x3A},		//   (146)  O - 0x00D8 Latin Capital Letter O with Stroke
	{0x3C,0x41,0x42,0x40,0x3C},		//   (147) `U - 0x00D9 Latin Capital Letter U with Grave
	{0x3C,0x40,0x42,0x41,0x3C},		//   (148) 'U - 0x00DA Latin Capital Letter U with Acute
	{0x3C,0x42,0x41,0x42,0x3C},		//   (149) ^U - 0x00DB Latin Capital Letter U with Circumflex
	{0x3C,0x41,0x40,0x41,0x3C},		//   (150) "U - 0x00DC Latin Capital Letter U with Diaeresis
	{0x0C,0x10,0x62,0x11,0x0C},		//   (151) `Y - 0x00DD Latin Capital Letter Y with Acute
	{0x7F,0x12,0x12,0x12,0x0C},		//   (152)  P - 0x00DE Latin Capital Letter Thom
	{0x40,0x3E,0x01,0x49,0x36},		//   (153)  B - 0x00DF Latin Capital Letter Sharp S
	{0x20,0x55,0x56,0x54,0x78},		//   (154) `a - 0x00E0 Latin Small Letter A with Grave
	{0x20,0x54,0x56,0x55,0x78},		//   (155) 'a - 0x00E1 Latin Small Letter A with Acute
	{0x20,0x56,0x55,0x56,0x78},		//   (156) ^a - 0x00E2 Latin Small Letter A with Circumflex
	{0x20,0x55,0x56,0x55,0x78},		//   (157) ~a - 0x00E3 Latin Small Letter A with Tilde
	{0x20,0x55,0x54,0x55,0x78},		//   (158) "a - 0x00E4 Latin Small Letter A with Diaeresis
	{0x20,0x56,0x57,0x56,0x78},		//   (159)  a - 0x00E5 Latin Small Letter A with Ring Above
	{0x24,0x54,0x78,0x54,0x58},		//   (160) ae - 0x00E6 Latin Small Letter Ae
	{0x0C,0x52,0x52,0x72,0x13},		//   (161)  c - 0x00E7 Latin Small Letter c with Cedilla
	{0x38,0x55,0x56,0x54,0x18},		//   (162) `e - 0x00E8 Latin Small Letter E with Grave
	{0x38,0x54,0x56,0x55,0x18},		//   (163) 'e - 0x00E9 Latin Small Letter E with Acute
	{0x38,0x56,0x55,0x56,0x18},		//   (164) ^e - 0x00EA Latin Small Letter E with Circumflex
	{0x38,0x55,0x54,0x55,0x18},		//   (165) "e - 0x00EB Latin Small Letter E with Diaeresis
	{0x00,0x49,0x7A,0x40,0x00},		//   (166) `i - 0x00EC Latin Small Letter I with Grave
	{0x00,0x48,0x7A,0x41,0x00},		//   (167) 'i - 0x00ED Latin Small Letter I with Acute
	{0x00,0x4A,0x79,0x42,0x00},		//   (168) ^i - 0x00EE Latin Small Letter I with Circumflex
	{0x00,0x4A,0x78,0x42,0x00},		//   (169) "i - 0x00EF Latin Small Letter I with Diaeresis
	{0x31,0x4A,0x4E,0x4A,0x30},		//   (170)    - 0x00F0 Latin Small Letter Eth
	{0x7A,0x11,0x0A,0x09,0x70},		//   (171) ~n - 0x00F1 Latin Small Letter N with Tilde
	{0x30,0x49,0x4A,0x48,0x30},		//   (172) `o - 0x00F2 Latin Small Letter O with Grave
	{0x30,0x48,0x4A,0x49,0x30},		//   (173) 'o - 0x00F3 Latin Small Letter O with Acute
	{0x30,0x4A,0x49,0x4A,0x30},		//   (174) ^o - 0x00F4 Latin Small Letter O with Circumflex
	{0x30,0x4A,0x49,0x4A,0x31},		//   (175) ~o - 0x00F5 Latin Small Letter O with Tilde
	{0x30,0x4A,0x48,0x4A,0x30},		//   (176) "o - 0x00F6 Latin Small Letter O with Diaeresis
	{0x08,0x08,0x2A,0x08,0x08},		//   (177)  + - 0x00F7 Division Sign
	{0x38,0x64,0x54,0x4C,0x38},		//   (178)  o - 0x00F8 Latin Small Letter O with Stroke
	{0x38,0x41,0x42,0x20,0x78},		//   (179) `u - 0x00F9 Latin Small Letter U with Grave
	{0x38,0x40,0x42,0x21,0x78},		//   (180) 'u - 0x00FA Latin Small Letter U with Acute
	{0x38,0x42,0x41,0x22,0x78},		//   (181) ^u - 0x00FB Latin Small Letter U with Circumflex
	{0x38,0x42,0x40,0x22,0x78},		//   (182) "u - 0x00FC Latin Small Letter U with Diaeresis
	{0x0C,0x50,0x52,0x51,0x3C},		//   (183) 'y - 0x00FD Latin Small Letter Y with Acute
	{0x7E,0x14,0x14,0x14,0x08},		//   (184)  p - 0x00FE Latin Small Letter Thom
	{0x0C,0x51,0x50,0x51,0x3C},		//   (185) "y - 0x00FF Latin Small Letter Y with Diaeresis
	{0x1E,0x09,0x09,0x29,0x5E},		//   (186)  A - 0x0104 Latin Capital Letter A with Ogonek
	{0x08,0x15,0x15,0x35,0x4E},		//   (187)  a - 0x0105 Latin Small Letter A with Ogonek
	{0x38,0x44,0x46,0x45,0x20},		//   (188) 'C - 0x0106 Latin Capital Letter C with Acute
	{0x30,0x48,0x4A,0x49,0x20},		//   (189) 'c - 0x0107 Latin Small Letter C with Acute
	{0x38,0x45,0x46,0x45,0x20},		//   (190)  C - 0x010C Latin Capital Letter C with Caron
	{0x30,0x49,0x4A,0x49,0x20},		//   (191)  c - 0x010D Latin Small Letter C with Caron
	{0x7C,0x45,0x46,0x45,0x38},		//   (192)  D - 0x010E Latin Capital Letter D with Caron
	{0x20,0x50,0x50,0x7C,0x03},		//   (193) d' - 0x010F Latin Small Letter D with Caron
	{0x1F,0x15,0x15,0x35,0x51},		//   (194)  E - 0x0118 Latin Capital Letter E with Ogonek
	{0x0E,0x15,0x15,0x35,0x46},		//   (195)  e - 0x0119 Latin Small Letter E with Ogonek
	{0x7C,0x55,0x56,0x55,0x44},		//   (196)  E - 0x011A Latin Capital Letter E with Caron
	{0x38,0x55,0x56,0x55,0x18},		//   (197)  e - 0x011B Latin Small Letter E with Caron
	{0x00,0x44,0x7C,0x40,0x00},		//   (198)  i - 0x0131 Latin Small Letter Dotless I
	{0x7F,0x48,0x44,0x40,0x40},		//   (199)  L - 0x0141 Latin Capital Letter L with Stroke
	{0x00,0x49,0x7F,0x44,0x00},		//   (200)  l - 0x0142 Latin Small Letter L with Stroke
	{0x7C,0x08,0x12,0x21,0x7C},		//   (201) 'N - 0x0143 Latin Capital Letter N with Acute
	{0x78,0x10,0x0A,0x09,0x70},		//   (202) 'n - 0x0144 Latin Small Letter N with Acute
	{0x7C,0x09,0x12,0x21,0x7C},		//   (203)  N - 0x0147 Latin Capital Letter N with Caron
	{0x78,0x11,0x0A,0x09,0x70},		//   (204)  n - 0x0148 Latin Small Letter N with Caron
	{0x38,0x47,0x44,0x47,0x38},		//   (205) "O - 0x0150 Latin Capital Letter O with Double Acute
	{0x30,0x4B,0x48,0x4B,0x30},		//   (206) "o - 0x0151 Latin Small Letter O with Double Acute
	{0x3E,0x41,0x7F,0x49,0x49},		//   (207) OE - 0x0152 Latin Capital Ligature Oe
	{0x38,0x44,0x38,0x54,0x58},		//   (208) oe - 0x0153 Latin Small Ligature Oe
	{0x7C,0x15,0x16,0x35,0x48},		//   (209)  R - 0x0158 Latin Capital Letter R with Caron
	{0x78,0x11,0x0A,0x09,0x10},		//   (210)  r - 0x0159 Latin Small Letter R with Caron
	{0x48,0x54,0x56,0x55,0x20},		//   (211) 'S - 0x015A Latin Capital Letter S with Acute
	{0x20,0x48,0x56,0x55,0x20},		//   (212) 's - 0x015B Latin Small Letter S with Acute
	{0x48,0x55,0x56,0x55,0x20},		//   (213)  S - 0x0160 Latin Capital Letter S with Caron
	{0x20,0x49,0x56,0x55,0x20},		//   (214)  s - 0x0161 Latin Small Letter S with Caron
	{0x04,0x05,0x7E,0x05,0x04},		//   (215)  T - 0x0164 Latin Capital Letter T with Caron
	{0x08,0x3C,0x48,0x22,0x01},		//   (216) t' - 0x0165 Latin Small Letter T with Caron
	{0x3C,0x42,0x45,0x42,0x3C},		//   (217)  U - 0x016E Latin Capital Letter U with Ring Above
	{0x38,0x42,0x45,0x22,0x78},		//   (218)  u - 0x016F Latin Small Letter U with Ring Above
	{0x3C,0x43,0x40,0x43,0x3C},		//   (219) "U - 0x0170 Latin Capital Letter U with Double Acute
	{0x38,0x43,0x40,0x23,0x78},		//   (220) "u - 0x0171 Latin Small Letter U with Double Acute
	{0x0C,0x11,0x60,0x11,0x0C},		//   (221) "Y - 0x0178 Latin Capital Letter Y with Diaeresis
	{0x44,0x66,0x55,0x4C,0x44},		//   (222) 'Z - 0x0179 Latin Capital Letter Z with Acute
	{0x48,0x6A,0x59,0x48,0x00},		//   (223) 'z - 0x017A Latin Small Letter Z with Acute
	{0x44,0x64,0x55,0x4C,0x44},		//   (224)  Z - 0x017B Latin Capital Letter Z with Dot Above
	{0x48,0x68,0x5A,0x48,0x00},		//   (225)  z - 0x017C Latin Small Letter Z with Dot Above
	{0x44,0x65,0x56,0x4D,0x44},		//   (226)  Z - 0x017D Latin Capital Letter Z with Caron
	{0x48,0x69,0x5A,0x49,0x00},		//   (227)  z - 0x017E Latin Small Letter Z with Caron
	{0x00,0x02,0x01,0x02,0x00},		//   (228)  ^ - 0x02C6 Modifier Letter Circumflex Accent
	{0x00,0x01,0x02,0x01,0x00},		//   (229)    - 0x02C7 Caron
	{0x00,0x01,0x01,0x01,0x00},		//   (230)    - 0x02C9 Modifier Letter Macron
	{0x01,0x02,0x02,0x01,0x00},		//   (231)    - 0x02D8 Breve
	{0x00,0x00,0x01,0x00,0x00},		//   (232)    - 0x02D9 Dot Above
	{0x00,0x02,0x05,0x02,0x00},		//   (233)    - 0x02DA Ring Above
	{0x02,0x01,0x02,0x01,0x00},		//   (234)  ~ - 0x02DC Small Tilde
	{0x7F,0x05,0x15,0x3A,0x50},		//   (235) Pt - 0x20A7 Peseta Sign
	{0x3E,0x55,0x55,0x41,0x22},		//   (236)  C - 0x20AC Euro Sign
	{0x18,0x14,0x08,0x14,0x0C},		//   (237)    - 0x221E Infinity
	{0x44,0x4A,0x4A,0x51,0x51},		//   (238)  < - 0x2264 Less-Than or Equal to
	{0x51,0x51,0x4A,0x4A,0x44},		//   (239)  > - 0x2265 Greater-Than or Equal to
	{0x74,0x42,0x41,0x42,0x74},		//   (240)    - 0x2302 House
};

//ASCII tabulka (recka a japonska pismena, ekvivalent Times New Roman, 5x8px)
/*unsigned char Ascii_2[108][5]={
	{0x00,0x00,0x00,0x00,0x00},		//
	{0x7E,0x11,0x11,0x11,0x7E},		//   (  1)  A - 0x0391 Greek Capital Letter Alpha
	{0x7F,0x49,0x49,0x49,0x36},		//   (  2)  B - 0x0392 Greek Capital Letter Beta
	{0x7F,0x02,0x01,0x01,0x03},		//   (  3)    - 0x0393 Greek Capital Letter Gamma
	{0x70,0x4E,0x41,0x4E,0x70},		//   (  4)    - 0x0394 Greek Capital Letter Delta
	{0x7F,0x49,0x49,0x49,0x41},		//   (  5)  E - 0x0395 Greek Capital Letter Epsilon
	{0x61,0x51,0x49,0x45,0x43},		//   (  6)  Z - 0x0396 Greek Capital Letter Zeta
	{0x7F,0x08,0x08,0x08,0x7F},		//   (  7)  H - 0x0397 Greek Capital Letter Eta
	{0x3E,0x49,0x49,0x49,0x3E},		//   (  8)    - 0x0398 Greek Capital Letter Theta
	{0x00,0x41,0x7F,0x41,0x00},		//   (  9)  I - 0x0399 Greek Capital Letter Iota
	{0x7F,0x08,0x14,0x22,0x41},		//   ( 10)  K - 0x039A Greek Capital Letter Kappa
	{0x70,0x0E,0x01,0x0E,0x70},		//   ( 11)    - 0x039B Greek Capital Letter Lamda
	{0x7F,0x02,0x0C,0x02,0x7F},		//   ( 12)  M - 0x039C Greek Capital Letter Mu
	{0x7F,0x04,0x08,0x10,0x7F},		//   ( 13)  N - 0x039D Greek Capital Letter Nu
	{0x63,0x5D,0x49,0x5D,0x63},		//   ( 14)    - 0x039E Greek Capital Letter Xi
	{0x3E,0x41,0x41,0x41,0x3E},		//   ( 15)  O - 0x039F Greek Capital Letter Omicron
	{0x41,0x3F,0x01,0x3F,0x41},		//   ( 16)    - 0x03A0 Greek Capital Letter Pi
	{0x7F,0x09,0x09,0x09,0x06},		//   ( 17)  P - 0x03A1 Greek Capital Letter Rho
	{0x63,0x55,0x49,0x41,0x41},		//   ( 18)    - 0x03A3 Greek Capital Letter Sigma
	{0x01,0x01,0x7F,0x01,0x01},		//   ( 19)  T - 0x03A4 Greek Capital Letter Tau
	{0x03,0x01,0x7E,0x01,0x03},		//   ( 20)    - 0x03A5 Greek Capital Letter Upsilon
	{0x08,0x55,0x7F,0x55,0x08},		//   ( 21)    - 0x03A6 Greek Capital Letter Phi
	{0x63,0x14,0x08,0x14,0x63},		//   ( 22)  X - 0x03A7 Greek Capital Letter Chi
	{0x07,0x48,0x7F,0x48,0x07},		//   ( 23)    - 0x03A8 Greek Capital Letter Psi
	{0x5E,0x61,0x01,0x61,0x5E},		//   ( 24)    - 0x03A9 Greek Capital Letter Omega
	{0x38,0x44,0x48,0x30,0x4C},		//   ( 25)  a - 0x03B1 Greek Small Letter Alpha
	{0x7C,0x2A,0x2A,0x2A,0x14},		//   ( 26)  B - 0x03B2 Greek Small Letter Beta
	{0x44,0x38,0x04,0x04,0x08},		//   ( 27)  r - 0x03B3 Greek Small Letter Gamma
	{0x30,0x4B,0x4D,0x59,0x30},		//   ( 28)    - 0x03B4 Greek Small Letter Delta
	{0x28,0x54,0x54,0x44,0x20},		//   ( 29)    - 0x03B5 Greek Small Letter Epsilon
	{0x00,0x18,0x55,0x52,0x22},		//   ( 30)    - 0x03B6 Greek Small Letter Zeta
	{0x3E,0x04,0x02,0x02,0x7C},		//   ( 31)  n - 0x03B7 Greek Small Letter Eta
	{0x3C,0x4A,0x4A,0x4A,0x3C},		//   ( 32)    - 0x03B8 Greek Small Letter Theta
	{0x00,0x3C,0x40,0x20,0x00},		//   ( 33)  i - 0x03B9 Greek Small Letter Iota
	{0x7C,0x10,0x28,0x44,0x40},		//   ( 34)  k - 0x03BA Greek Small Letter Kappa
	{0x41,0x32,0x0C,0x30,0x40},		//   ( 35)    - 0x03BB Greek Small Letter Lamda
	{0x7E,0x20,0x20,0x10,0x3E},		//   ( 36)  u - 0x03BC Greek Small Letter Mu
	{0x1C,0x20,0x40,0x20,0x1C},		//   ( 37)  v - 0x03BD Greek Small Letter Nu
	{0x14,0x2B,0x2A,0x2A,0x60},		//   ( 38)    - 0x03BE Greek Small Letter Xi
	{0x38,0x44,0x44,0x44,0x38},		//   ( 39)  o - 0x03BF Greek Small Letter Omicron
	{0x44,0x3C,0x04,0x7C,0x44},		//   ( 40)    - 0x03C0 Greek Small Letter Pi
	{0x70,0x28,0x24,0x24,0x18},		//   ( 41)  p - 0x03C1 Greek Small Letter Rho
	{0x0C,0x12,0x12,0x52,0x60},		//   ( 42)    - 0x03C2 Greek Small Letter Final Sigma
	{0x38,0x44,0x4C,0x54,0x24},		//   ( 43)    - 0x03C3 Greek Small Letter Sigma
	{0x04,0x3C,0x44,0x20,0x00},		//   ( 44)  t - 0x03C4 Greek Small Letter Tau
	{0x3C,0x40,0x40,0x20,0x1C},		//   ( 45)  v - 0x03C5 Greek Small Letter Upsilon
	{0x18,0x24,0x7E,0x24,0x18},		//   ( 46)    - 0x03C6 Greek Small Letter Phi
	{0x44,0x28,0x10,0x28,0x44},		//   ( 47)  x - 0x03C7 Greek Small Letter Chi
	{0x0C,0x10,0x7E,0x10,0x0C},		//   ( 48)    - 0x03C8 Greek Small Letter Psi
	{0x38,0x44,0x30,0x44,0x38},		//   ( 49)  w - 0x03C9 Greek Small Letter Omega
	{0x0A,0x0A,0x4A,0x2A,0x1E},		//   ( 50)    - 0xFF66 Katakana Letter Wo
	{0x04,0x44,0x34,0x14,0x0C},		//   ( 51)    - 0xFF67 Katakana Letter Small A
	{0x20,0x10,0x78,0x04,0x00},		//   ( 52)    - 0xFF68 Katakana Letter Small I
	{0x18,0x08,0x4C,0x48,0x38},		//   ( 53)    - 0xFF69 Katakana Letter Small U
	{0x48,0x48,0x78,0x48,0x48},		//   ( 54)    - 0xFF6A Katakana Letter Small E
	{0x48,0x28,0x18,0x7C,0x08},		//   ( 55)    - 0xFF6B Katakana Letter Small O
	{0x08,0x7C,0x08,0x28,0x18},		//   ( 56)    - 0xFF6C Katakana Letter Small Ya
	{0x40,0x48,0x48,0x78,0x40},		//   ( 57)    - 0xFF6D Katakana Letter Small Yu
	{0x54,0x54,0x54,0x7C,0x00},		//   ( 58)    - 0xFF6E Katakana Letter Small Yo
	{0x18,0x00,0x58,0x40,0x38},		//   ( 59)    - 0xFF6F Katakana Letter Small Tu
	{0x08,0x08,0x08,0x08,0x08},		//   ( 60)    - 0xFF70 Katakana-Hiragana Prolonged Sound Mark
	{0x01,0x41,0x3D,0x09,0x07},		//   ( 61)    - 0xFF71 Katakana Letter A
	{0x10,0x08,0x7C,0x02,0x01},		//   ( 62)    - 0xFF72 Katakana Letter I
	{0x0E,0x02,0x43,0x22,0x1E},		//   ( 63)    - 0xFF73 Katakana Letter U
	{0x42,0x42,0x7E,0x42,0x42},		//   ( 64)    - 0xFF74 Katakana Letter E
	{0x22,0x12,0x0A,0x7F,0x02},		//   ( 65)    - 0xFF75 Katakana Letter O
	{0x42,0x3F,0x02,0x42,0x3E},		//   ( 66)    - 0xFF76 Katakana Letter Ka
	{0x0A,0x0A,0x7F,0x0A,0x0A},		//   ( 67)    - 0xFF77 Katakana Letter Ki
	{0x08,0x46,0x42,0x22,0x1E},		//   ( 68)    - 0xFF78 Katakana Letter Ku
	{0x04,0x03,0x42,0x3E,0x02},		//   ( 69)    - 0xFF79 Katakana Letter Ke
	{0x42,0x42,0x42,0x42,0x7E},		//   ( 70)    - 0xFF7A Katakana Letter Ko
	{0x02,0x4F,0x22,0x1F,0x02},		//   ( 71)    - 0xFF7B Katakana Letter Sa
	{0x4A,0x4A,0x40,0x20,0x1C},		//   ( 72)    - 0xFF7C Katakana Letter Shi
	{0x42,0x22,0x12,0x2A,0x46},		//   ( 73)    - 0xFF7D Katakana Letter Su
	{0x02,0x3F,0x42,0x4A,0x46},		//   ( 74)    - 0xFF7E Katakana Letter Se
	{0x06,0x48,0x40,0x20,0x1E},		//   ( 75)    - 0xFF7F Katakana Letter So
	{0x08,0x46,0x4A,0x32,0x1E},		//   ( 76)    - 0xFF80 Katakana Letter Ta
	{0x0A,0x4A,0x3E,0x09,0x08},		//   ( 77)    - 0xFF81 Katakana Letter Chi
	{0x0E,0x00,0x4E,0x20,0x1E},		//   ( 78)    - 0xFF82 Katakana Letter Tsu
	{0x04,0x45,0x3D,0x05,0x04},		//   ( 79)    - 0xFF83 Katakana Letter Te
	{0x00,0x7F,0x08,0x10,0x00},		//   ( 80)    - 0xFF84 Katakana Letter To
	{0x44,0x24,0x1F,0x04,0x04},		//   ( 81)    - 0xFF85 Katakana Letter Na
	{0x40,0x42,0x42,0x42,0x40},		//   ( 82)    - 0xFF86 Katakana Letter Ni
	{0x42,0x2A,0x12,0x2A,0x06},		//   ( 83)    - 0xFF87 Katakana Letter Nu
	{0x22,0x12,0x7B,0x16,0x22},		//   ( 84)    - 0xFF88 Katakana Letter Ne
	{0x00,0x40,0x20,0x1F,0x00},		//   ( 85)    - 0xFF89 Katakana Letter No
	{0x78,0x00,0x02,0x04,0x78},		//   ( 86)    - 0xFF8A Katakana Letter Ha
	{0x3F,0x44,0x44,0x44,0x44},		//   ( 87)    - 0xFF8B Katakana Letter Hi
	{0x02,0x42,0x42,0x22,0x1E},		//   ( 88)    - 0xFF8C Katakana Letter Fu
	{0x04,0x02,0x04,0x08,0x30},		//   ( 89)    - 0xFF8D Katakana Letter He
	{0x32,0x02,0x7F,0x02,0x32},		//   ( 90)    - 0xFF8E Katakana Letter Ho
	{0x02,0x12,0x22,0x52,0x0E},		//   ( 91)    - 0xFF8F Katakana Letter Ma
	{0x00,0x2A,0x2A,0x2A,0x40},		//   ( 92)    - 0xFF90 Katakana Letter Mi
	{0x38,0x24,0x22,0x20,0x70},		//   ( 93)    - 0xFF91 Katakana Letter Mu
	{0x40,0x28,0x10,0x28,0x06},		//   ( 94)    - 0xFF92 Katakana Letter Me
	{0x0A,0x3E,0x4A,0x4A,0x4A},		//   ( 95)    - 0xFF93 Katakana Letter Mo
	{0x04,0x7F,0x04,0x14,0x0C},		//   ( 96)    - 0xFF94 Katakana Letter Ya
	{0x40,0x42,0x42,0x7E,0x40},		//   ( 97)    - 0xFF95 Katakana Letter Yu
	{0x4A,0x4A,0x4A,0x4A,0x7E},		//   ( 98)    - 0xFF96 Katakana Letter Yo
	{0x04,0x05,0x45,0x25,0x1C},		//   ( 99)    - 0xFF97 Katakana Letter Ra
	{0x0F,0x40,0x20,0x1F,0x00},		//   (100)    - 0xFF98 Katakana Letter Ri
	{0x7C,0x00,0x7E,0x40,0x30},		//   (101)    - 0xFF99 Katakana Letter Ru
	{0x7E,0x40,0x20,0x10,0x08},		//   (102)    - 0xFF9A Katakana Letter Re
	{0x7E,0x42,0x42,0x42,0x7E},		//   (103)    - 0xFF9B Katakana Letter Ro
	{0x0E,0x02,0x42,0x22,0x1E},		//   (104)    - 0xFF9C Katakana Letter Wa
	{0x42,0x42,0x40,0x20,0x18},		//   (105)    - 0xFF9D Katakana Letter N
	{0x02,0x04,0x01,0x02,0x00},		//   (106)    - 0xFF9E Katakana Voiced Sound Mark
	{0x07,0x05,0x07,0x00,0x00},		//   (107)    - 0xFF9F Katakana Semi-Voiced Sound Mark
};*/



//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Vyplneni pameti daty (full screen) - vhodne pro clear screen
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void Fill_RAM(unsigned char Data)
{
unsigned char i,j;

	Set_Column_Address(0x00,0x77);
	Set_Row_Address(0x00,0x7F);
	Set_Write_RAM();

	for(i=0;i<128;i++)
	{
		for(j=0;j<120;j++)
		{
			Write_Data(Data);
			Write_Data(Data);
		}
	}
}


//=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Globalni promenne
//=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#define Max_Column	0x3F			// 256/4-1
#define Max_Row		0x3F			// 64-1
#define	Brightness	0x0F


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Funkce pro zobrazeni textu na displeji s moznosti posudu po pixelech
//	a: Index sloupce pocatecniho pixelu (0-255)
//  b: Index radku pcoatecniho pixelu (0-63)
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

void Write_Text(unsigned char TextX[], unsigned char a, unsigned char b)
{
	unsigned char i,pos,rep;
	unsigned char pom0,pom1;
	unsigned char col,len,lich,k;
	if(a<4)
	pos=a;
	else
	pos=a%4;

	col=0x1C+((a-pos)/4);
	Set_Column_Address(col, col);
	Set_Row_Address(b, b+8);
	Set_Write_RAM();

	k=0;
	len=strlen(TextX);
	unsigned char Text[len];

	for(i=0;i<len;i++)
	{
		Text[i]=TextX[i]-32;
	}



if(pos==0)
{
	lich=len%2;
	rep=len/2;
	k=0;

	if(len>1)
	{
		for(k=0;k<rep;k++)
		{

			for(i=0;i<=7;i++)
			{



				pom0=0;
				pom1=0;

				if((Ascii_1[Text[0+(2*k)]][0] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_1[Text[0+(2*k)]][1] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_1[Text[0+(2*k)]][2] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_1[Text[0+(2*k)]][3] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_1[Text[0+(2*k)]][4] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;


				if((Ascii_1[Text[1+(2*k)]][0] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_1[Text[1+(2*k)]][1] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);

			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;
				if((Ascii_1[Text[1+(2*k)]][2] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_1[Text[1+(2*k)]][3] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_1[Text[1+(2*k)]][4] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();
		}
	}
	if(lich==1)
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][0] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-1]][1] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			if((Ascii_1[Text[len-1]][2] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_1[Text[len-1]][3] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;

			Write_Data(pom0);
			Write_Data(pom1);
		}

		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;
			if((Ascii_1[Text[len-1]][4] & 1<<i)==(1<<i))
			pom0+=240;
			else
			pom0+=0;

			Write_Data(pom0);
			Write_Data(pom1);
		}
	}
}

if(pos==1)
{
	lich=len%2;
	rep=(len-1)/2;
	k=0;
	for(i=0;i<=7;i++)
	{
		pom0=0;
		pom1=0;

		if((Ascii_1[Text[0]][0] & 1<<i)==(1<<i))
		pom0=15;
		else
		pom0=0;
		
		if((Ascii_1[Text[0]][1] & 1<<i)==(1<<i))
		pom1=240;
		else
		pom1=0;
		if((Ascii_1[Text[0]][2] & 1<<i)==(1<<i))
		pom1+=15;
		else
		pom1+=0;

		Write_Data(pom0);
		Write_Data(pom1);
	}
	col++;
	Set_Column_Address(col, col);
	Set_Row_Address(b,b+7);
	Set_Write_RAM();
	
	if(len>2)
	{
		for(k=0;k<rep;k++)
		{

			for(i=0;i<=7;i++)
			{



				pom0=0;
				pom1=0;

				if((Ascii_1[Text[0+(2*k)]][3] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_1[Text[0+(2*k)]][4] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_1[Text[1+(2*k)]][0] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_1[Text[1+(2*k)]][1] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_1[Text[1+(2*k)]][2] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;


				if((Ascii_1[Text[1+(2*k)]][3] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_1[Text[1+(2*k)]][4] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);

			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;
				if((Ascii_1[Text[2+(2*k)]][0] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_1[Text[2+(2*k)]][1] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_1[Text[2+(2*k)]][2] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();
		}
	}
	if(lich==1)
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][3] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-1]][4] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			Write_Data(pom0);
			Write_Data(pom1);
		}

	}
	else
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-2]][3] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-2]][4] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_1[Text[len-1]][0] & 1<<i)==(1<<i))
			pom1=15;
			else
			pom1=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}
		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][1] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-1]][2] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_1[Text[len-1]][3] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_1[Text[len-1]][4] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}


	}
}

if(pos==2)
{
	lich=len%2;
	rep=(len-1)/2;
	k=0;
	for(i=0;i<=7;i++)
	{
		pom0=0;
		pom1=0;

		if((Ascii_1[Text[0]][0] & 1<<i)==(1<<i))
		pom1=240;
		else
		pom1=0;
		if((Ascii_1[Text[0]][1] & 1<<i)==(1<<i))
		pom1+=15;
		else
		pom1+=0;

		Write_Data(pom0);
		Write_Data(pom1);
	}
	col++;
	Set_Column_Address(col, col);
	Set_Row_Address(b,b+7);
	Set_Write_RAM();

	if(len>2)
	{
		for(k=0;k<rep;k++)
		{

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_1[Text[0+(2*k)]][2] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_1[Text[0+(2*k)]][3] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_1[Text[0+(2*k)]][4] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_1[Text[1+(2*k)]][0] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_1[Text[1+(2*k)]][1] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;


				if((Ascii_1[Text[1+(2*k)]][2] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_1[Text[1+(2*k)]][3] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);

			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;
				if((Ascii_1[Text[1+(2*k)]][4] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;

				if((Ascii_1[Text[2+(2*k)]][0] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_1[Text[2+(2*k)]][1] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();
		}
	}
	if(lich==1)
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][2] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-1]][3] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			if((Ascii_1[Text[len-1]][4] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			

			Write_Data(pom0);
			Write_Data(pom1);
		}

	}
	else
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-2]][2] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-2]][3] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_1[Text[len-2]][4] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}
		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][0] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-1]][1] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_1[Text[len-1]][2] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_1[Text[len-1]][3] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}

		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][4] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			
			Write_Data(pom0);
			Write_Data(pom1);
		}


	}
}
if(pos==3)
{
	lich=len%2;
	rep=(len-1)/2;
	k=0;
	for(i=0;i<=7;i++)
	{
		pom0=0;
		pom1=0;

		if((Ascii_1[Text[0]][0] & 1<<i)==(1<<i))
		pom1+=15;
		else
		pom1+=0;

		Write_Data(pom0);
		Write_Data(pom1);
	}
	col++;
	Set_Column_Address(col, col);
	Set_Row_Address(b,b+7);
	Set_Write_RAM();

	if(len>2)
	{
		for(k=0;k<rep;k++)
		{

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_1[Text[0+(2*k)]][1] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_1[Text[0+(2*k)]][2] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_1[Text[0+(2*k)]][3] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_1[Text[0+(2*k)]][4] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;


				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_1[Text[1+(2*k)]][0] & 1<<i)==(1<<i))
				pom0=15;
				else
				pom0+=0;


				if((Ascii_1[Text[1+(2*k)]][1] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_1[Text[1+(2*k)]][2] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);

			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;
				if((Ascii_1[Text[1+(2*k)]][3] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_1[Text[1+(2*k)]][4] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;


				if((Ascii_1[Text[2+(2*k)]][0] & 1<<i)==(1<<i))
				pom1=15;
				else
				pom1=0;
				
				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();
		}
	}
	if(lich==1)
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][1] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-1]][2] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			if((Ascii_1[Text[len-1]][3] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_1[Text[len-1]][4] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;
			

			Write_Data(pom0);
			Write_Data(pom1);
		}

	}
	else
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-2]][1] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-2]][2] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_1[Text[len-2]][3] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_1[Text[len-2]][4] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}
		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][0] & 1<<i)==(1<<i))
			pom0=15;
			else
			pom0=0;
			
			if((Ascii_1[Text[len-1]][1] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_1[Text[len-1]][2] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}

		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_1[Text[len-1]][3] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_1[Text[len-1]][4] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			Write_Data(pom0);
			Write_Data(pom1);

		}


	}
}
}

//Funkce pro psani reckych pismen
/*
void Write_Greek(unsigned char TextX[], unsigned char a, unsigned char b)
{
	unsigned char i,pos,rep;
	unsigned char pom0,pom1;
	unsigned char col,len,lich,k;
	if(a<4)
	pos=a;
	else
	pos=a%4;

	col=0x1C+((a-pos)/4);
	Set_Column_Address(col, col);
	Set_Row_Address(b, b+8);
	Set_Write_RAM();

	k=0;
	len=strlen(TextX);
	unsigned char Text[len];

	for(i=0;i<len;i++)
	{
		Text[i]=TextX[i]-32;
	}




if(pos==0)
{
	lich=len%2;
	rep=len/2;
	//Write_Data(0xFA); //D0
	//Write_Data(0x60); //D1
	k=0;

	if(len>1)
	{
		for(k=0;k<rep;k++)
		{

			for(i=0;i<=7;i++)
			{



				pom0=0;
				pom1=0;

				if((Ascii_2[Text[0+(2*k)]][0] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_2[Text[0+(2*k)]][1] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_2[Text[0+(2*k)]][2] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_2[Text[0+(2*k)]][3] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_2[Text[0+(2*k)]][4] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;


				if((Ascii_2[Text[1+(2*k)]][0] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_2[Text[1+(2*k)]][1] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);

			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;
				if((Ascii_2[Text[1+(2*k)]][2] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_2[Text[1+(2*k)]][3] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_2[Text[1+(2*k)]][4] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();
		}
	}
	if(lich==1)
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][0] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-1]][1] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			if((Ascii_2[Text[len-1]][2] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_2[Text[len-1]][3] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;

			Write_Data(pom0);
			Write_Data(pom1);
		}

		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;
			if((Ascii_2[Text[len-1]][4] & 1<<i)==(1<<i))
			pom0+=240;
			else
			pom0+=0;

			Write_Data(pom0);
			Write_Data(pom1);
		}
	}
}

if(pos==1)
{
	lich=len%2;
	rep=(len-1)/2;
	//Write_Data(0xFA); //D0
	//Write_Data(0x60); //D1
	k=0;
	for(i=0;i<=7;i++)
	{
		pom0=0;
		pom1=0;

		if((Ascii_2[Text[0]][0] & 1<<i)==(1<<i))
		pom0=15;
		else
		pom0=0;
		
		if((Ascii_2[Text[0]][1] & 1<<i)==(1<<i))
		pom1=240;
		else
		pom1=0;
		if((Ascii_2[Text[0]][2] & 1<<i)==(1<<i))
		pom1+=15;
		else
		pom1+=0;

		Write_Data(pom0);
		Write_Data(pom1);
	}
	col++;
	Set_Column_Address(col, col);
	Set_Row_Address(b,b+7);
	Set_Write_RAM();
	
	if(len>2)
	{
		for(k=0;k<rep;k++)
		{

			for(i=0;i<=7;i++)
			{



				pom0=0;
				pom1=0;

				if((Ascii_2[Text[0+(2*k)]][3] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_2[Text[0+(2*k)]][4] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_2[Text[1+(2*k)]][0] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_2[Text[1+(2*k)]][1] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_2[Text[1+(2*k)]][2] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;


				if((Ascii_2[Text[1+(2*k)]][3] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_2[Text[1+(2*k)]][4] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);

			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;
				if((Ascii_2[Text[2+(2*k)]][0] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_2[Text[2+(2*k)]][1] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_2[Text[2+(2*k)]][2] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();
		}
	}
	if(lich==1)
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][3] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-1]][4] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			Write_Data(pom0);
			Write_Data(pom1);
		}

	}
	else
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-2]][3] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-2]][4] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_2[Text[len-1]][0] & 1<<i)==(1<<i))
			pom1=15;
			else
			pom1=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}
		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][1] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-1]][2] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_2[Text[len-1]][3] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_2[Text[len-1]][4] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}


	}
}

if(pos==2)
{
	lich=len%2;
	rep=(len-1)/2;
	//Write_Data(0xFA); //D0
	//Write_Data(0x60); //D1
	k=0;
	for(i=0;i<=7;i++)
	{
		pom0=0;
		pom1=0;

		if((Ascii_2[Text[0]][0] & 1<<i)==(1<<i))
		pom1=240;
		else
		pom1=0;
		if((Ascii_2[Text[0]][1] & 1<<i)==(1<<i))
		pom1+=15;
		else
		pom1+=0;

		Write_Data(pom0);
		Write_Data(pom1);
	}
	col++;
	Set_Column_Address(col, col);
	Set_Row_Address(b,b+7);
	Set_Write_RAM();

	if(len>2)
	{
		for(k=0;k<rep;k++)
		{

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_2[Text[0+(2*k)]][2] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_2[Text[0+(2*k)]][3] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_2[Text[0+(2*k)]][4] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_2[Text[1+(2*k)]][0] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_2[Text[1+(2*k)]][1] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;


				if((Ascii_2[Text[1+(2*k)]][2] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_2[Text[1+(2*k)]][3] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);

			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;
				if((Ascii_2[Text[1+(2*k)]][4] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;

				if((Ascii_2[Text[2+(2*k)]][0] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_2[Text[2+(2*k)]][1] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();
		}
	}
	if(lich==1)
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][2] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-1]][3] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			if((Ascii_2[Text[len-1]][4] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			

			Write_Data(pom0);
			Write_Data(pom1);
		}

	}
	else
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-2]][2] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-2]][3] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_2[Text[len-2]][4] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}
		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][0] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-1]][1] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_2[Text[len-1]][2] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_2[Text[len-1]][3] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}

		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][4] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			
			Write_Data(pom0);
			Write_Data(pom1);
		}


	}
}
if(pos==3)
{
	lich=len%2;
	rep=(len-1)/2;
	//Write_Data(0xFA); //D0
	//Write_Data(0x60); //D1
	k=0;
	for(i=0;i<=7;i++)
	{
		pom0=0;
		pom1=0;

		if((Ascii_2[Text[0]][0] & 1<<i)==(1<<i))
		pom1+=15;
		else
		pom1+=0;

		Write_Data(pom0);
		Write_Data(pom1);
	}
	col++;
	Set_Column_Address(col, col);
	Set_Row_Address(b,b+7);
	Set_Write_RAM();

	if(len>2)
	{
		for(k=0;k<rep;k++)
		{

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_2[Text[0+(2*k)]][1] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_2[Text[0+(2*k)]][2] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;

				if((Ascii_2[Text[0+(2*k)]][3] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_2[Text[0+(2*k)]][4] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;


				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;

				if((Ascii_2[Text[1+(2*k)]][0] & 1<<i)==(1<<i))
				pom0=15;
				else
				pom0+=0;


				if((Ascii_2[Text[1+(2*k)]][1] & 1<<i)==(1<<i))
				pom1=240;
				else
				pom1=0;
				if((Ascii_2[Text[1+(2*k)]][2] & 1<<i)==(1<<i))
				pom1+=15;
				else
				pom1+=0;

				Write_Data(pom0);
				Write_Data(pom1);

			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();

			for(i=0;i<=7;i++)
			{
				pom0=0;
				pom1=0;
				if((Ascii_2[Text[1+(2*k)]][3] & 1<<i)==(1<<i))
				pom0=240;
				else
				pom0=0;
				if((Ascii_2[Text[1+(2*k)]][4] & 1<<i)==(1<<i))
				pom0+=15;
				else
				pom0+=0;


				if((Ascii_2[Text[2+(2*k)]][0] & 1<<i)==(1<<i))
				pom1=15;
				else
				pom1=0;
				
				Write_Data(pom0);
				Write_Data(pom1);
			}

			col++;
			Set_Column_Address(col, col);
			Set_Row_Address(b,b+7);
			Set_Write_RAM();
		}
	}
	if(lich==1)
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][1] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-1]][2] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			if((Ascii_2[Text[len-1]][3] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_2[Text[len-1]][4] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;
			

			Write_Data(pom0);
			Write_Data(pom1);
		}

	}
	else
	{
		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-2]][1] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-2]][2] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;
			
			if((Ascii_2[Text[len-2]][3] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_2[Text[len-2]][4] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}
		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][0] & 1<<i)==(1<<i))
			pom0=15;
			else
			pom0=0;
			
			if((Ascii_2[Text[len-1]][1] & 1<<i)==(1<<i))
			pom1=240;
			else
			pom1=0;
			if((Ascii_2[Text[len-1]][2] & 1<<i)==(1<<i))
			pom1+=15;
			else
			pom1+=0;


			Write_Data(pom0);
			Write_Data(pom1);
		}

		col++;
		Set_Column_Address(col, col);
		Set_Row_Address(b,b+7);
		Set_Write_RAM();

		for(i=0;i<=7;i++)
		{
			pom0=0;
			pom1=0;

			if((Ascii_2[Text[len-1]][3] & 1<<i)==(1<<i))
			pom0=240;
			else
			pom0=0;
			if((Ascii_2[Text[len-1]][4] & 1<<i)==(1<<i))
			pom0+=15;
			else
			pom0+=0;

			Write_Data(pom0);
			Write_Data(pom1);

		}


	}
}
}*/

//funkce pro vykreslovani obrazku z pameti


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Funkce pro zobrazeni grafiky na displeji s moznosti posunu po pixelech
//	a: sirka obrazku v pixelech (1-256)
//  b: vyska obrazku v pixelech (1-64)
//  c: souradnice pocatku na ose x (0-255)
//  d: souradnice pocatku na ose y (0-63)
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void Draw_Picture(unsigned char *Picture_Pointer, unsigned char a, unsigned char b, unsigned char c, unsigned char d)
{
unsigned char *Src_Pointer;
unsigned char i,j,rep;
unsigned char pom0, pom1, pom2, pom3, vys0, vys1;
unsigned char col0, col1, col;
unsigned char ord0, ord1;

if(c<4)
ord0=c;
else
ord0=c%4;
if(c+a-1<4)
ord1=(a+c-1);
else
ord1=(a+c-1)%4;

col0=c/4;			//vypocet indexu prvniho sloupce
col1=(a+c-1)/4;		//vypocet indexu posledniho sloupce
col=col1-col0+1;	//vypocet poctu sloupcu



Src_Pointer=Picture_Pointer;
Set_Column_Address(0x1C+col0,0x1C+col1);
Set_Row_Address(d,d+b-1);
Set_Write_RAM();

if((a==1)&(ord0==1)&(ord1==1))
{
	for(i=0;i<b;i++)
	{
			pom0=0;
			
			pom0=*Src_Pointer;
			Src_Pointer++;
			
			vys0=(pom0&0x0F);
			vys1=0;

			Write_Data(vys0);
			Write_Data(vys1);	
	}
}
if((a==1)&(ord0==2)&(ord1==2))
{
	for(i=0;i<b;i++)
	{
			pom0=0;
			
			pom0=*Src_Pointer;
			Src_Pointer++;
			
			vys0=0;
			vys1=((pom0<<4) & 0xF0);
			
			Write_Data(vys0);
			Write_Data(vys1);	
	}
}
if((a==2)&(ord0==1)&(ord1==2))
{
	for(i=0;i<b;i++)
	{
			pom0=0;
			pom1=0;



			pom0=*Src_Pointer;
			Src_Pointer++;
			pom1=*Src_Pointer;
			Src_Pointer++;
		
			vys0=(pom0&0x0F);
			vys1=((pom1<<4) & 0xF0);

			Write_Data(vys0);
			Write_Data(vys1);
	}
}
else
{
	if(ord0==0)
	rep=col;
	else
	rep=col-1;

	if(ord1==3)
	rep=rep;
	else
	rep=rep-1;

	for(i=0;i<b;i++)
	{
		if(ord0==1)
		{
			pom0=0;
			pom1=0;
			pom2=0;
			
			pom0=*Src_Pointer;
			Src_Pointer++;
			pom1=*Src_Pointer;
			Src_Pointer++;
			pom2=*Src_Pointer;
			Src_Pointer++;
			

			vys0=(pom0&0x0F);
			vys1=((pom1<<4) & 0xF0)|(pom2&0x0F);

			Write_Data(vys0);
			Write_Data(vys1);
		}	

		if(ord0==2)
		{
			pom0=0;
			pom1=0;
					
			pom0=*Src_Pointer;
			Src_Pointer++;
			pom1=*Src_Pointer;
			Src_Pointer++;
		
			vys0=0;
			vys1=((pom0<<4) & 0xF0)|(pom1&0x0F);

			Write_Data(vys0);
			Write_Data(vys1);
		}
		
		if(ord0==3)
		{
			pom0=0;
								
			pom0=*Src_Pointer;
			Src_Pointer++;
				
			vys0=0;
			vys1=pom0&0x0F;

			Write_Data(vys0);
			Write_Data(vys1);
		}
		
		for(j=0;j<rep;j++)
		{
			pom0=0;
			pom1=0;
			pom2=0;
			pom3=0;


			pom0=*Src_Pointer;
			Src_Pointer++;
			pom1=*Src_Pointer;
			Src_Pointer++;
			pom2=*Src_Pointer;
			Src_Pointer++;
			pom3=*Src_Pointer;
			Src_Pointer++;

			vys0=((pom0<<4) & 0xF0)|(pom1&0x0F);
			vys1=((pom2<<4) & 0xF0)|(pom3&0x0F);

			Write_Data(vys0);
			Write_Data(vys1);
		}
		
		if(ord1==0)	
		{
			pom0=0;
								
			pom0=*Src_Pointer;
			Src_Pointer++;
				
			vys0=(pom0<<4) & 0xF0;
			vys1=0;

			Write_Data(vys0);
			Write_Data(vys1);
		}

		if(ord1==1)	
		{
			pom0=0;
			pom1=0;
								
			pom0=*Src_Pointer;
			Src_Pointer++;
			pom1=*Src_Pointer;
			Src_Pointer++;
				
			vys0=((pom0<<4) & 0xF0)|(pom1&0x0F);
			vys1=0;

			Write_Data(vys0);
			Write_Data(vys1);
		}

		if(ord1==2)	
		{
			pom0=0;
			pom1=0;
			pom2=0;

			pom0=*Src_Pointer;
			Src_Pointer++;
			pom1=*Src_Pointer;
			Src_Pointer++;
			pom2=*Src_Pointer;
			Src_Pointer++;

			vys0=((pom0<<4) & 0xF0)|(pom1&0x0F);
			vys1=((pom2<<4) & 0xF0);

			Write_Data(vys0);
			Write_Data(vys1);

		}

	}




}


}

//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Fade In (Full Screen)
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void Fade_In()
{
unsigned int i;	

	Set_Display_On_Off(0x01);
	for(i=0;i<(Brightness+1);i++)
	{
		Set_Master_Current(i);
		_delay_ms(25);
	
	}
}


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Fade Out (Full Screen)
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void Fade_Out()
{
unsigned int i;	

	for(i=(Brightness+1);i>0;i--)
	{
		Set_Master_Current(i-1);
		_delay_ms(25);
	
	}
	Set_Display_On_Off(0x00);
}






//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Nastaveni tabulky sedi
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void Set_Gray_Scale_Table() //vlastni tabulka sedi (koriguje prubeh intenzity zareni na linearni)
{
	Write_Command(0xB8);			// Set Gray Scale Table
	Write_Data(0x00);			//   Gray Scale Level 1
	Write_Data(0x01);			//   Gray Scale Level 2
	Write_Data(0x03);			//   Gray Scale Level 3
	Write_Data(0x06);			//   Gray Scale Level 4
	Write_Data(0x0A);			//   Gray Scale Level 5
	Write_Data(0x10);			//   Gray Scale Level 6
	Write_Data(0x1A);			//   Gray Scale Level 7
	Write_Data(0x28);			//   Gray Scale Level 8
	Write_Data(0x37);			//   Gray Scale Level 9
	Write_Data(0x47);			//   Gray Scale Level 10
	Write_Data(0x58);			//   Gray Scale Level 11
	Write_Data(0x6A);			//   Gray Scale Level 12
	Write_Data(0x7F);			//   Gray Scale Level 13
	Write_Data(0x96);			//   Gray Scale Level 14
	Write_Data(0xB4);			//   Gray Scale Level 15

	Write_Command(0x00);			// Nastavi pouziti nastavene tabulky sedi
}


void Set_Linear_Gray_Scale_Table() //linearni tabulka sedi
{
	Write_Command(0xB9);			// Set Default Linear Gray Scale Table
}


//=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Inicializace displeje (podle doporuceneho nastaveni (viz datasheet Densitron))
//=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void OLED_Init()
{
	DDRA=0xFF; //nastaveni bran A a B jako vystupnich
	DDRB=0xFF;
	
	BS0=1; //nastaveni komunikacniho modu
	BS1=1;
	
	RES=0;
	_delay_ms(100); //
	RES=1;

	Set_Command_Lock(0x12);			// Odemkne radic pro zadavani prikazu
	Set_Display_On_Off(0x00);		// Vypnuti displeje (0x00|0x01)
	Set_Display_Clock(0x91);		// Nastaveni hodin
	Set_Multiplex_Ratio(0x3F);		// 1/64 strida
	Set_Display_Offset(0x00);		// Posun Mapovaciho citace pameti (0x00~0x5F)
	Set_Start_Line(0x00);			// Nastaveni mapovani radku pameti ramSet (0x00~0x7F)
	Set_Remap_Format(0x14);			// Nastaveni sloupce na pozici 0 k segmentu 0 displeje
						//     Vypnuti premapovani horniho a dolniho nibblu
						//     Inkrementuje nejdrive horizontalni adresa
					
	Set_GPIO(0x00);				// Nastaveni napetove urovne LOW pro vyvod segmentu
	Set_Function_Selection(0x01);		// Zapnuti interniho Vdd
//	Set_Enhancement_A(0xA0,0xFD);		// Enable External VSL (neni pouzito, takze zakomentovano)
	Set_Contrast_Current(0xDF);		// Nastaveni rozsahu vystupniho proudu segmentu
	Set_Master_Current(Brightness);		// Nastaveni rozsahu vystupniho proudu segmentu
	Set_Gray_Scale_Table();			// Nastaveni sirky pulsu pro zobrazeni sede - z Gray Scale Table
	Set_Phase_Length(0xE8);			// Nastaveni faze 1 jako 5 hodinovych cyklu a faze 2 jako 14 hodinovych cyklu
	Set_Enhancement_B(0x82);		
	Set_Precharge_Voltage(0x1F);		
	Set_Precharge_Period(0x08);		
	Set_VCOMH(0x07);			
	Set_Display_Mode(0x02);			// Nastaveni normalniho modu displeje (0x00/0x01/0x02/0x03)
	Set_Partial_Display(0x01,0x00,0x00);

	Fill_RAM(0x00);				// Smazani obrazovky
	
	PWR=0b1; // pripnuti napajeciho zdroje k 15V napajeci vetvi displeje

	_delay_ms(100); //zpozdeni - cekani na ustaleni napeti

	Set_Display_On_Off(0x01);		// Zapnuti displeje (0x00/0x01)
}

//Procedura pro vypnuti displeje
void OLED_quit()
{
	unsigned char i;
	Set_Display_On_Off(0x00);		// Vypnuti displeje (0x00/0x01)
	
	PWR=0b0; // Odpojeni napajeciho napeti 15V od displeje
	for(i=0; i<5; i++)
	{
	_delay_ms(100);
	}
}


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//  Funkce main - demonstrace naprogramovane funkcnosti
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void main()
{


	OLED_Init(); //inicializace displeje
	Draw_Picture(logo_FEKT,24,24,0,0);
	Write_Text("Diplomov prce",107,24);
	Write_Text("Vladislav Bartosik",80,32);
	Fade_In();
	

	
	
}

